Learn R Programming

gmwmx (version 1.0.3)

PBO_get_station: Load station data from PBO

Description

Load station data from PBO

Usage

PBO_get_station(station_name, column, time_range = c(-Inf, Inf), scale = 1)

Value

A gnssts object that contains the data associated with the specified PBO station.

Arguments

station_name

A string specifying the PBO station name.

column

A string specifying the name of the column to extract.

time_range

A vector of 2 specifying the time range of data to extract.

scale

A scalar specifying an optional scaling parameter applied to the extracted data.

Examples

Run this code
if (FALSE) {
pbo_cola_data = PBO_get_station("COLA", column="dE")
str(pbo_cola_data)
}

Run the code above in your browser using DataLab