powered by
Load station data from PBO
PBO_get_station(station_name, column, time_range = c(-Inf, Inf), scale = 1)
A gnssts object that contains the data associated with the specified PBO station.
gnssts
A string specifying the PBO station name.
string
A string specifying the name of the column to extract.
A vector of 2 specifying the time range of data to extract.
vector
A scalar specifying an optional scaling parameter applied to the extracted data.
scalar
if (FALSE) { pbo_cola_data = PBO_get_station("COLA", column="dE") str(pbo_cola_data) }
Run the code above in your browser using DataLab