create_A_matrix: Define matrix A of the functional model
Description
Define matrix A of the functional model
Usage
create_A_matrix(t_nogap, jumps, n_seasonal)
Value
Matrix A in order to compute the functional component of the model in a linear fashion
Arguments
t_nogap
A vector specifying the index of the time series.
jumps
A vector specifying the time at which there is a mean shift of the time series. Should be specified to NULL if there is not presence of offsets in the signal.
n_seasonal
An integer specifying the number of sinusoidal signals in the time series.